Run dos2unix on recently added patch files

^M characters... they make my eyes BLEED
This commit is contained in:
Josh Boyer 2015-03-26 07:49:10 -04:00
parent b4512393ac
commit 984fc80fab
3 changed files with 1937 additions and 1937 deletions

File diff suppressed because it is too large Load Diff

View File

@ -1,46 +1,46 @@
From 3bba3a1990d065e30630c5c67ed32689106aef57 Mon Sep 17 00:00:00 2001 From 3bba3a1990d065e30630c5c67ed32689106aef57 Mon Sep 17 00:00:00 2001
From: Mark Salter <msalter@redhat.com> From: Mark Salter <msalter@redhat.com>
Date: Wed, 25 Mar 2015 14:17:50 -0400 Date: Wed, 25 Mar 2015 14:17:50 -0400
Subject: [PATCH 4/4] arm64: avoid needing console= to enable serial console Subject: [PATCH 4/4] arm64: avoid needing console= to enable serial console
Tell kernel to prefer one of the serial ports for console on Tell kernel to prefer one of the serial ports for console on
platforms currently supported (pl011 or 8250). console= on platforms currently supported (pl011 or 8250). console= on
command line will override these assumed preferences. This is command line will override these assumed preferences. This is
just a hack to get the behavior we want from DT provided by just a hack to get the behavior we want from DT provided by
firmware. firmware.
Signed-off-by: Mark Salter <msalter@redhat.com> Signed-off-by: Mark Salter <msalter@redhat.com>
--- ---
arch/arm64/kernel/setup.c | 19 +++++++++++++++++++ arch/arm64/kernel/setup.c | 19 +++++++++++++++++++
1 file changed, 19 insertions(+) 1 file changed, 19 insertions(+)
diff --git a/arch/arm64/kernel/setup.c b/arch/arm64/kernel/setup.c diff --git a/arch/arm64/kernel/setup.c b/arch/arm64/kernel/setup.c
index e8420f6..8473381 100644 index e8420f6..8473381 100644
--- a/arch/arm64/kernel/setup.c --- a/arch/arm64/kernel/setup.c
+++ b/arch/arm64/kernel/setup.c +++ b/arch/arm64/kernel/setup.c
@@ -547,3 +547,22 @@ const struct seq_operations cpuinfo_op = { @@ -547,3 +547,22 @@ const struct seq_operations cpuinfo_op = {
.stop = c_stop, .stop = c_stop,
.show = c_show .show = c_show
}; };
+ +
+/* +/*
+ * Temporary hack to avoid need for console= on command line + * Temporary hack to avoid need for console= on command line
+ */ + */
+static int __init arm64_console_setup(void) +static int __init arm64_console_setup(void)
+{ +{
+ /* Allow cmdline to override our assumed preferences */ + /* Allow cmdline to override our assumed preferences */
+ if (console_set_on_cmdline) + if (console_set_on_cmdline)
+ return 0; + return 0;
+ +
+ if (IS_ENABLED(CONFIG_SERIAL_AMBA_PL011)) + if (IS_ENABLED(CONFIG_SERIAL_AMBA_PL011))
+ add_preferred_console("ttyAMA", 0, "115200"); + add_preferred_console("ttyAMA", 0, "115200");
+ +
+ if (IS_ENABLED(CONFIG_SERIAL_8250)) + if (IS_ENABLED(CONFIG_SERIAL_8250))
+ add_preferred_console("ttyS", 0, "115200"); + add_preferred_console("ttyS", 0, "115200");
+ +
+ return 0; + return 0;
+} +}
+early_initcall(arm64_console_setup); +early_initcall(arm64_console_setup);
-- --
1.9.3 1.9.3

View File

@ -1,44 +1,44 @@
From 30b01a7a85c0a2993870f7ed93059f9957bff59f Mon Sep 17 00:00:00 2001 From 30b01a7a85c0a2993870f7ed93059f9957bff59f Mon Sep 17 00:00:00 2001
From: Mark Langsdorf <mlangsdo@redhat.com> From: Mark Langsdorf <mlangsdo@redhat.com>
Date: Wed, 25 Mar 2015 14:12:51 -0400 Date: Wed, 25 Mar 2015 14:12:51 -0400
Subject: [PATCH 3/4] usb: make xhci platform driver use 64 bit or 32 bit DMA Subject: [PATCH 3/4] usb: make xhci platform driver use 64 bit or 32 bit DMA
The xhci platform driver needs to work on systems that either only The xhci platform driver needs to work on systems that either only
support 64-bit DMA or only support 32-bit DMA. Attempt to set a support 64-bit DMA or only support 32-bit DMA. Attempt to set a
coherent dma mask for 64-bit DMA, and attempt again with 32-bit coherent dma mask for 64-bit DMA, and attempt again with 32-bit
DMA if that fails. DMA if that fails.
Signed-off-by: Mark Langsdorf <mlangsdo@redhat.com> Signed-off-by: Mark Langsdorf <mlangsdo@redhat.com>
--- ---
drivers/usb/host/xhci-plat.c | 15 +++++++-------- drivers/usb/host/xhci-plat.c | 15 +++++++--------
1 file changed, 7 insertions(+), 8 deletions(-) 1 file changed, 7 insertions(+), 8 deletions(-)
diff --git a/drivers/usb/host/xhci-plat.c b/drivers/usb/host/xhci-plat.c diff --git a/drivers/usb/host/xhci-plat.c b/drivers/usb/host/xhci-plat.c
index 0e11d61..cc5ca2c 100644 index 0e11d61..cc5ca2c 100644
--- a/drivers/usb/host/xhci-plat.c --- a/drivers/usb/host/xhci-plat.c
+++ b/drivers/usb/host/xhci-plat.c +++ b/drivers/usb/host/xhci-plat.c
@@ -83,14 +83,13 @@ static int xhci_plat_probe(struct platform_device *pdev) @@ -83,14 +83,13 @@ static int xhci_plat_probe(struct platform_device *pdev)
if (irq < 0) if (irq < 0)
return -ENODEV; return -ENODEV;
- /* Initialize dma_mask and coherent_dma_mask to 32-bits */ - /* Initialize dma_mask and coherent_dma_mask to 32-bits */
- ret = dma_set_coherent_mask(&pdev->dev, DMA_BIT_MASK(32)); - ret = dma_set_coherent_mask(&pdev->dev, DMA_BIT_MASK(32));
- if (ret) - if (ret)
- return ret; - return ret;
- if (!pdev->dev.dma_mask) - if (!pdev->dev.dma_mask)
- pdev->dev.dma_mask = &pdev->dev.coherent_dma_mask; - pdev->dev.dma_mask = &pdev->dev.coherent_dma_mask;
- else - else
- dma_set_mask(&pdev->dev, DMA_BIT_MASK(32)); - dma_set_mask(&pdev->dev, DMA_BIT_MASK(32));
+ /* Try setting the coherent_dma_mask to 64 bits, then try 32 bits */ + /* Try setting the coherent_dma_mask to 64 bits, then try 32 bits */
+ ret = dma_set_mask_and_coherent(&pdev->dev, DMA_BIT_MASK(64)); + ret = dma_set_mask_and_coherent(&pdev->dev, DMA_BIT_MASK(64));
+ if (ret) { + if (ret) {
+ ret = dma_set_mask_and_coherent(&pdev->dev, DMA_BIT_MASK(32)); + ret = dma_set_mask_and_coherent(&pdev->dev, DMA_BIT_MASK(32));
+ if (ret) + if (ret)
+ return ret; + return ret;
+ } + }
hcd = usb_create_hcd(driver, &pdev->dev, dev_name(&pdev->dev)); hcd = usb_create_hcd(driver, &pdev->dev, dev_name(&pdev->dev));
if (!hcd) if (!hcd)
-- --
1.9.3 1.9.3